Summary:	Network monitoring tools including ping
Name:		iputils
Version:	20240905
Release:	%mkrel 1
License:	BSD
Group:		System/Base
URL:		https://github.com/iputils/iputils
Source0:	https://github.com/iputils/iputils/archive/%{version}/%{name}-%{version}.tar.gz
# ifenslave.c seems to come from linux-2.6.25/Documentation/networking/ifenslave.c
Source1:	ifenslave.c
# bonding.txt seems to come from linux-2.6.25/Documentation/networking/bonding.txt
Source2:	bonding.txt
Source3:	ifenslave.8
Source4:	ninfod.service

Patch100:	iputils-ifenslave.patch
Requires(pre):	filesystem >= 2.1.9-18
BuildRequires:	docbook-dtd31-sgml
BuildRequires:	docbook5-style-xsl
BuildRequires:	gettext
BuildRequires:	pkgconfig(libidn2)
BuildRequires:	iproute2
BuildRequires:	libsysfs-devel
BuildRequires:	meson
BuildRequires:	pkgconfig(openssl)
BuildRequires:	pkgconfig(libcap)
BuildRequires:	pkgconfig(libxslt)
BuildRequires:	pkgconfig(gnutls)
BuildRequires:	libgcrypt-devel
BuildRequires:	xsltproc

Requires:	traceroute

%description
The iputils package contains ping, a basic networking tool. The ping command
sends a series of ICMP protocol ECHO_REQUEST packets to a specified network
host and can tell you if that machine is alive and receiving network traffic.

%package	ninfod
Summary:	Node Information Query Daemon
Requires:	%{name} = %{version}-%{release}
Group:		System/Base
Requires(post):	rpm-helper >= %{rpmhelper_required_version}
Requires(preun): rpm-helper >= %{rpmhelper_required_version}

%description	ninfod
Node Information Query (RFC4620) daemon. Responds to IPv6 Node Information
Queries.

%prep
%setup -q -n %{name}-%{version}

cp %{SOURCE1} .
cp %{SOURCE2} .
cp %{SOURCE3} .
cp %{SOURCE4} .

%autopatch -p1

%build
%serverbuild
%meson
%meson_build
gcc -Wall %{optflags} $CFLAGS $LDFLAGS ifenslave.c -o ifenslave

%install
install -d %{buildroot}%{_sbindir}
install -d %{buildroot}%{_bindir}
install -d %{buildroot}%{_unitdir}
install -d %{buildroot}%{_mandir}/man8

%meson_install
%find_lang %{name}

ln -s ping %{buildroot}%{_bindir}/ping6
ln -s ../bin/tracepath %{buildroot}%{_sbindir}/tracepath
ln -s ../bin/tracepath %{buildroot}%{_sbindir}/tracepath6
ln -s ../bin/arping %{buildroot}%{_sbindir}/arping
ln -s traceroute %{buildroot}%{_sbindir}/traceroute6
install -cp ifenslave %{buildroot}%{_sbindir}/
install -cp ifenslave.8 %{buildroot}%{_mandir}/man8/
install -cp ninfod.service %{buildroot}%{_unitdir}
rm -rf %{buildroot}%{_sysconfdir}/init.d

%pretrans -p <lua>
st = posix.stat(rpm.expand("{_bindir}/ping6"))
if st and st.type ~= "link" then
   os.remove(rpm.expand("{_bindir}/ping6"))
end
st = posix.stat(rpm.expand("{_sbindir}/tracepath6"))
if st and st.type ~= "link" then
   os.remove(rpm.expand("{_sbindir}/tracepath6"))
end
st = posix.stat(rpm.expand("{_sbindir}/tracepath"))
if st and st.type ~= "link" then
   os.remove(rpm.expand("{_sbindir}/tracepath"))
end
st = posix.stat(rpm.expand("{_sbindir}/arping"))
if st and st.type ~= "link" then
   os.remove(rpm.expand("{_sbindir}/arping"))
end

%post ninfod
%_post_service ninfod

%preun ninfod
%_preun_service ninfod

%files -f %{name}.lang
%doc bonding.txt
%{_bindir}/clockdiff
%attr(4755,root,root)	%{_bindir}/ping
%{_bindir}/arping
%{_sbindir}/arping
%{_sbindir}/ifenslave
%{_bindir}/ping6
%{_sbindir}/tracepath6
%{_bindir}/tracepath
%{_sbindir}/tracepath
%{_sbindir}/traceroute6
%{_mandir}/man8/*

%files ninfod
%{_unitdir}/ninfod.service


%changelog
* Fri Jan 24 2025 mrambo3501 <mrambo3501> 20240905-1.mga10
+ Revision: 2141195
- version 20240905

* Fri Apr 05 2024 wally <wally> 20240117-2.mga10
+ Revision: 2054628
- basesystem rebuild for i686

* Thu Feb 15 2024 daviddavid <daviddavid> 20240117-1.mga10
+ Revision: 2041328
- new version: 20240117

* Sun Dec 04 2022 joequant <joequant> 20221126-1.mga9
+ Revision: 1917893
- update to 20221126

* Sat Apr 02 2022 umeabot <umeabot> 20211215-2.mga9
+ Revision: 1840574
- Mageia 9 Mass Rebuild

* Tue Jan 25 2022 mrambo3501 <mrambo3501> 20211215-1.mga9
+ Revision: 1769685
- verison 20211215
- remove obsolete meson build parameter
- update files list

* Thu Aug 05 2021 luigiwalser <luigiwalser> 20210722-1.mga9
+ Revision: 1739588
- 20210722

* Tue Mar 02 2021 daviddavid <daviddavid> 20210202-1.mga9
+ Revision: 1696236
- new version: 20210202

* Sun Nov 29 2020 luigiwalser <luigiwalser> 20200821-2.mga8
+ Revision: 1650431
- rebuild for nettle

* Tue Nov 03 2020 luigiwalser <luigiwalser> 20200821-1.mga8
+ Revision: 1642289
- add ninfod subpackage
- 20200821 (partial sync with fedora)

* Wed Aug 05 2020 joequant <joequant> 20180629-5.mga8
+ Revision: 1611119
- fix common

* Sun Feb 16 2020 umeabot <umeabot> 20180629-4.mga8
+ Revision: 1534261
- Mageia 8 Mass Rebuild

* Tue Oct 01 2019 daviddavid <daviddavid> 20180629-3.mga8
+ Revision: 1448569
- rebuild for new nettle 3.5.1

* Thu Feb 21 2019 daviddavid <daviddavid> 20180629-2.mga7
+ Revision: 1369029
- rebuild for new libidn2 2.1.1

* Mon Jan 14 2019 luigiwalser <luigiwalser> 20180629-1.mga7
+ Revision: 1356263
- BR xsltproc
- 20180629

* Sun Sep 23 2018 umeabot <umeabot> 20161105-4.mga7
+ Revision: 1298316
- Mageia 7 Mass Rebuild

* Fri May 11 2018 kekepower <kekepower> 20161105-3.mga7
+ Revision: 1228371
- Rebuild for libidn 1.35

* Wed Aug 23 2017 ovitters <ovitters> 20161105-2.mga7
+ Revision: 1144638
+ rebuild (emptylog)

* Mon Nov 28 2016 daviddavid <daviddavid> 20161105-2.mga6
+ Revision: 1070574
- requires traceroute (fixes dangling symlink "/usr/sbin/traceroute6 -> traceroute")

* Sat Nov 12 2016 luigiwalser <luigiwalser> 20161105-1.mga6
+ Revision: 1066763
- traceroute6 is a symlink now
- 20161105
- tracepath6 is a symlink now

* Thu Jun 02 2016 ngompa <ngompa> 20160308-2.mga6
+ Revision: 1019785
- Convert %%pretrans script from shell to Lua (by proyvind)

* Mon May 09 2016 luigiwalser <luigiwalser> 20160308-1.mga6
+ Revision: 1011621
- ping6 is a symlink now
- 20160308

* Fri Jan 01 2016 luigiwalser <luigiwalser> 20151218-1.mga6
+ Revision: 917527
- 20151218

* Tue Dec 22 2015 oden <oden> 20140620-6.mga6
+ Revision: 913365
- drop apparmor support as it's not in mageia, (profiles only in traceroute and iputils)

* Thu Sep 10 2015 fwang <fwang> 20140620-5.mga6
+ Revision: 875450
- rebuild for new libgcrypt

* Fri Aug 21 2015 tmb <tmb> 20140620-4.mga6
+ Revision: 867523
- rebuild for new gcc

* Wed Oct 15 2014 umeabot <umeabot> 20140620-3.mga5
+ Revision: 747407
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 20140620-2.mga5
+ Revision: 680553
- Mageia 5 Mass Rebuild

* Sun Sep 07 2014 tmb <tmb> 20140620-1.mga5
+ Revision: 673364
- BR: libgcrypt-devel
- update to 2014-06-20
- drop all ancient non-applied patches
- update url

* Fri Oct 18 2013 umeabot <umeabot> 20121221-3.mga4
+ Revision: 506092
- Mageia 4 Mass Rebuild

* Sat Jan 12 2013 umeabot <umeabot> 20121221-2.mga3
+ Revision: 354475
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Jan 06 2013 tmb <tmb> 20121221-1.mga3
+ Revision: 339794
- BR gnutls-devel
- BR libcap-devel
- update tp 20121221

* Sat Jul 21 2012 colin <colin> 20101006-4.mga3
+ Revision: 273158
- Update for usrmove

* Thu Jun 09 2011 pterjan <pterjan> 20101006-3.mga2
+ Revision: 102373
- Drop Patch18 which purpose seems to be to cause a segfault

* Mon Jan 17 2011 misc <misc> 20101006-2.mga2
+ Revision: 21051
- remove old Conflicts dating back to mdv 2008.0 and mdk 10.2

* Mon Jan 17 2011 misc <misc> 20101006-2.mga1
+ Revision: 21047
- rebuilt for new python
+ blino <blino>
- imported package iputils


* Tue Nov 23 2010 Eugeni Dodonov <eugeni@mandriva.com> 20101006-1mdv2011.0
+ Revision: 600271
- Updated to 20101006.
  Drop P22 (merged upstream).

* Sun Aug 22 2010 Tomasz Pawel Gajc <tpg@mandriva.org> 20100418-1mdv2011.0
+ Revision: 572040
- add buildrequires on openssl-devel
- update to new version 20100418
- rediff patches 4,6,7,9,12,15
- diable patches 13 and 14
- Patch22: prevent ping against DOS attacks

  + Oden Eriksson <oeriksson@mandriva.com>
    - P22: security fix for CVE-2010-2529

* Sun Apr 18 2010 Tomasz Pawel Gajc <tpg@mandriva.org> 20100214-1mdv2010.1
+ Revision: 536085
- update to new version 20100214
- drop patch 5, fixed by upstream
- split patch 8 into patch 19 and 20
- Patch21: deal correctly with optflags
- provide better version of patch 11
- disable patches 4,6,7,9,12,14 and 15 (hard to guess which one is still needed, probably none)

* Sun Mar 14 2010 Oden Eriksson <oeriksson@mandriva.com> 20071127-8mdv2010.1
+ Revision: 519011
- rebuild

* Wed Sep 02 2009 Christophe Fergeau <cfergeau@mandriva.com> 20071127-7mdv2010.0
+ Revision: 425374
- rebuild

* Sun Dec 21 2008 Oden Eriksson <oeriksson@mandriva.com> 20071127-6mdv2009.1
+ Revision: 316953
- rediffed one fuzzy patch
- fix build with -Werror=format-security (P17)

  + Olivier Blin <oblin@mandriva.com>
    - revert explicit provide of /sbin/arping, it is handled in media_info/file-deps

  + Frederic Crozat <fcrozat@mandriva.com>
    - add explicit provides for /sbin/arping, fix upgrade from 2008.1

* Sun Jul 27 2008 Oden Eriksson <oeriksson@mandriva.com> 20071127-5mdv2009.0
+ Revision: 250431
- rebuild

* Tue Jul 08 2008 Oden Eriksson <oeriksson@mandriva.com> 20071127-4mdv2009.0
+ Revision: 232779
- sync patches with iputils-20071127-3.fc10.src.rpm
- use more up to date ifenslave code
- "ping www.r?\195?\164ksm?\195?\182rg?\195?\165s.se" works now

  + Thierry Vignaud <tv@mandriva.org>
    - rebuild
    - fix no-buildroot-tag

* Sat Jan 26 2008 Tomasz Pawel Gajc <tpg@mandriva.org> 20071127-2mdv2008.1
+ Revision: 158286
- looks like OPEN_MAX define has been removed from kernel's limits.h, fix this with patch 5
- add more ICMP return codes with patch 6 from Debian

  + Thierry Vignaud <tv@mandriva.org>
    - rebuild with fixed %%serverbuild macro

* Sun Dec 30 2007 Tomasz Pawel Gajc <tpg@mandriva.org> 20071127-1mdv2008.1
+ Revision: 139639
- new snapshot
- drop useless buildrequires

* Mon Dec 17 2007 Thierry Vignaud <tv@mandriva.org> 20070202-3mdv2008.1
+ Revision: 127142
- kill re-definition of %%buildroot on Pixel's request

* Wed Sep 19 2007 Andreas Hasenack <andreas@mandriva.com> 20070202-3mdv2008.0
+ Revision: 91193
- ship apparmor profile and use it if apparmor is in effect

* Wed Jun 27 2007 Andreas Hasenack <andreas@mandriva.com> 20070202-2mdv2008.0
+ Revision: 45087
- using serverbuild macro (-fstack-protector-all)

* Fri Apr 20 2007 Olivier Blin <oblin@mandriva.com> 20070202-1mdv
+ Revision: 16253
- fix URL
- 20070202 version
- Patch0: fix build by using s_addr field
- drop rh7 patch
- drop merged datalen patch and buggy datalen patches
- rediff ping_sparcfix and rdisc-server patches
- drop ipv6calc, it is now in its own package


* Sun Mar 18 2007 Oden Eriksson <oeriksson@mandriva.com> 20020927-10mdv2007.1
+ Revision: 145736
- prevent man page file clashes

* Sat Mar 17 2007 Oden Eriksson <oeriksson@mandriva.com> 20020927-9mdv2007.1
+ Revision: 145453
- rebuild
- rebuild
- Import iputils

* Wed Nov 22 2006 Oden Eriksson <oeriksson@mandriva.com> 20020927-7
- bunzip patches
- spec file massage

* Sat Dec 31 2005 Mandriva Linux Team <http://www.mandrivaexpert.com/> 
- Rebuild

* Sun May 16 2004 Luca Berra <bluca@vodka.it> 20020927-5mdk 
- bonding 1.1.0 from kernel source + debian manpage

